excel — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- export »

# excel

`camelot.view.export.excel.` `write_data_to_excel`(filename, title, headerList, data_list)

  @param filename: the file to which to save the exported excel @param title: title to put in the first row of the genarated excel file @param headerList: list of header definitions @param data_list: list or generator with the row data

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- export »

Comments
blog comments powered by Disqus